@@ -1,20 +1,22 @@
 #' @title Get full Complete Journey transactions data set.
 #'
-#' @description 
+#' @description
 #' The complete transactions data set for the Complete Journey is too large to be
 #' contained within the package. \code{get_transactions()} provides an efficient
 #' method for downloading the full data set from the source GitHub repository.
-#' 
-#' @param verbose Logical indicator whether or not to download silently.      
-#'      
+#'
+#' @param verbose Logical indicator whether or not to download silently.
+#'
 #' @source Downloading from \url{https://github.com/bradleyboehmke/completejourney/tree/master/data}.
-#'   Data originated from 84.51°, Customer Journey study, \url{http://www.8451.com/area51/} 
+#'   Data originated from 84.51°, Customer Journey study, \url{http://www.8451.com/area51/}
 #'   and were processes for analysis.
-#' 
-#' @return A data frame with 1,469,307 rows and 5 variables
-#' 
+#'
+#' @return A data frame with 1,469,307 rows and 11 variables. Returns \code{NULL}
+#'   if the download fails (e.g., network timeout, GitHub unavailability) with
+#'   an informative message about the failure.
+#'
 #' @seealso \code{\link{transactions_sample}} for details regarding the variables.
-#' 
+#'
 #' @examples
 #' \donttest{
 #' # requires internet connection
@@ -22,5 +24,5 @@
 #' }
 #' @export
 get_transactions <- function(verbose = FALSE) {
-  download_data(which = 'transactions', verbose = verbose)
-}
\ No newline at end of file
+  download_data(which = "transactions", verbose = verbose)
+}
